# Strict Filtering
### On this page
  * [Filtering on relations without strict filtering](https://help.sap.com/docs/leanix/ea/strict-filtering#filtering-on-relations-without-strict-filtering)
  * [Filtering on relation fields without strict filtering](https://help.sap.com/docs/leanix/ea/strict-filtering#filtering-on-relation-fields-without-strict-filtering)
  * [Strict filtering for filters on relations](https://help.sap.com/docs/leanix/ea/strict-filtering#strict-filtering-for-filters-on-relations)
  * [Strict Filtering with filters for fields on relations](https://help.sap.com/docs/leanix/ea/strict-filtering#strict-filtering-with-filters-for-fields-on-relations)


Users filtering for related fact sheets or for fields on relations need to understand the nuances of which fact sheets are retrieved and what happens to the attributes and relations on those fact sheets in connection with the filters.
Using filters on relations or the 'Advanced Search' to filter on relation fields requires a certain explanation of the functionality.
